{% load static %}
<!doctype html>

<head>
<!-- Google Tag Manager -->
  {% if environment == "production" %}
  <!-- Production Environment -->
    <script>
        (function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
        new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
        j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
        'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
        })(window,document,'script','dataLayer','GTM-M32M5N5')
    </script>
  {% else %}
  <!-- Non-Production Environment (staging or dev) -->
    <script>
      (function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
      new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
      j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
      'https://www.googletagmanager.com/gtm.js?id='+i+dl+ '&gtm_auth=ZZqc7ZNE1mTX6vrV43Q_7g&gtm_preview=env-6&gtm_cookies_win=x';f.parentNode.insertBefore(j,f);
      })(window,document,'script','dataLayer','GTM-M32M5N5');
    </script>
  {% endif %}
<!-- End Google Tag Manager -->
  <title>Kurono</title>
  <link rel="shortcut icon" href="{% static 'favicon.ico' %}" type="image/x-icon">
  <style type="text/css">
    body {
      margin: 0;
      padding: 0;
      overflow: hidden;
    }
  </style>
</head>

<body>
<!-- Google Tag Manager (noscript) -->
  {% if environment == "production" %}
  <!-- Production Environment -->
    <noscript>
        <iframe src="https://www.googletagmanager.com/ns.html?id=GTM-M32M5N5"
        height="0" width="0" style="display:none;visibility:hidden">
        </iframe>
    </noscript>
  {% else %}
  <!-- Non-Production Environment (staging or dev) -->
      <noscript>
        <iframe src="https://www.googletagmanager.com/ns.html?id=GTM-M32M5N5&gtm_auth=ZZqc7ZNE1mTX6vrV43Q_7g&gtm_preview=env-6&gtm_cookies_win=x"
        height="0" width="0" style="display:none;visibility:hidden">
        </iframe>
    </noscript>
  {% endif %}
<!-- End Google Tag Manager (noscript) -->
  <div id="root"></div>
</body>
<script src="{% static 'react/src.580b38b6.js' %}"></script>